clear all

* Directory
* For replicator: change the directory to your own local ones
local owndir = "C:\replication package"
global datadir_raw = "`owndir'/data/raw" // Raw data stored here
global datadir_proc = "`owndir'/data/proc" // Processed data stored here
global outputdir = "`owndir'/output"
global codedir = "`owndir'/code"

/* -----------------------------------
 Calculate South-North relative wages for each race
----------------------------------- */
foreach race_sample in entire white black {
	cd "$datadir_raw"
	use census1940_2020_raw, clear

    
	if "`race_sample'" == "entire" {
		do "$codedir/DataClearing.do"
		sort year region sector
		reshape wide wage, i(year region) j(sector) // wage1: average agricultural wage in region i in year t

		* Define regional average wage = equation (1) in Caselli-Coleman. weighted average of sectoral wage
		gen wage_region = agri*wage1+nonagri*wage2
		keep year region wage_region north midwest south west 
		reshape wide wage_region, i(year) j(region)
		gen wage_s_relative = wage_region3/wage_region1
		keep year wage_s_relative

		save "$outputdir/fig1_entire.dta", replace
	}
	else if "`race_sample'" == "white" {
		keep if race ==1 
		do "$codedir/DataClearing.do"
		sort year region sector
		reshape wide wage, i(year region) j(sector) // wage1: average agricultural wage in region i in year t

		* Define regional average wage = equation (1) in Caselli-Coleman. weighted average of sectoral wage
		gen wage_region = agri*wage1+nonagri*wage2
		keep year region wage_region north midwest south west 
		reshape wide wage_region, i(year) j(region)
		gen wage_s_relative = wage_region3/wage_region1
		rename wage_s_relative wage_s_relative_w
		keep year wage_s_relative_w

		save "$outputdir/fig1_white.dta", replace
	}
	else if "`race_sample'" == "black" {
		keep if race ==2 
		do "$codedir/DataClearing.do"
		sort year region sector
		reshape wide wage, i(year region) j(sector) // wage1: average agricultural wage in region i in year t

		* Define regional average wage = equation (1) in Caselli-Coleman. weighted average of sectoral wage
		gen wage_region = agri*wage1+nonagri*wage2
		keep year region wage_region north midwest south west 
		reshape wide wage_region, i(year) j(region)
		gen wage_s_relative = wage_region3/wage_region1
		rename wage_s_relative wage_s_relative_b
		keep year wage_s_relative_b

		save "$outputdir/fig1_black.dta", replace
	}
}


/* -----------------------------------
 Merge Datasets and Plotting
----------------------------------- */
cd "$outputdir"

use fig1_entire.dta,clear
merge 1:1 year using fig1_white, nogenerate
merge 1:1 year using fig1_black, nogenerate
save Figure1.dta, replace 

label variable wage_s_relative "Entire Population"
label variable wage_s_relative_w "Whites"
label variable wage_s_relative_b "Blacks"

twoway (connected wage_s_relative_w year, lcolor(black%30) lwidth(0.75) lpattern("--")  mcolor(black%30) msymbol(O))  ///
	   (connected wage_s_relative year, lcolor(black) lwidth(0.75) msymbol(none) mcolor(black) xlab(1940(10)2020, grid) ylab(0.4(0.1)1.0) ) ///
	   (connected wage_s_relative_b year, lcolor(black%70) lwidth(0.75) lpattern("-.-") msymbol(D) lcolor(black%70) mcolor(black%70) ), ///
xtitle("Year") ytitle("South / North relative wage") graphregion(color(white)) ///
legend(region(lwidth(0.1)) ring(0) pos(5) col(1))
graph export "$outputdir/Figure1.pdf", replace

/* -----------------------------------
 Removing interim dataset
----------------------------------- */
cap rm fig1_entire.dta 
cap rm fig1_white.dta
cap rm fig1_black.dta 
