/* ======================================
Project Title: Racial Heterogeneity in the U.S. Structural Transformation and Regional Convergence  
Authors: Minki Kim and Munseob Lee  
Last modified: Aug 4, 2023 

This code replicates Table 3
====================================== */ 

clear all

* Directory
* For replicator: change the directory to your own local ones
local owndir = "C:\replication package"
global datadir_raw = "`owndir'/data/raw" // Raw data stored here
global datadir_proc = "`owndir'/data/proc" // Processed data stored here
global outputdir = "`owndir'/output"
global codedir = "`owndir'/code"

cd "$codedir"

/* -----------------------------------
 Table 3
----------------------------------- */
foreach race_sample in entire white black {
	cd "$datadir_raw"
	use census1940_2020_raw, clear
	local year_begin 1990
	local year_end 2020
    
	if "`race_sample'" == "entire" {
		tab race
		do "$codedir/DataClearing.do"
		include "$codedir/Decomposition.do"
		tostring dummy, replace
		replace dummy = "Entire Population" if _n == 1
		replace dummy = "Percentage" if _n == 2
		save "$outputdir/tab3_p1.dta", replace
	}
	else if "`race_sample'" == "white" {
		keep if race ==1 
		tab race
		do "$codedir/DataClearing.do"
		include "$codedir/Decomposition.do"
		tostring dummy, replace
		replace dummy = "White" if _n == 1
		replace dummy = "Percentage" if _n == 2
		save "$outputdir/tab3_p2.dta", replace

	}
	else if "`race_sample'" == "black" {
		keep if race ==2 
		tab race
		do "$codedir/DataClearing.do"
		include "$codedir/Decomposition.do"
		tostring dummy, replace
		replace dummy = "Black" if _n == 1
		replace dummy = "Percentage" if _n == 2
		save "$outputdir/tab3_p3.dta", replace

	}
}

/* -----------------------------------
 Generate Table 
----------------------------------- */
cd "$outputdir"

use tab3_p1, clear
append using tab3_p2
append using tab3_p3
save Table3.dta, replace 

format Total %9.3f
format Labor_Reallocation %9.3f
format Between_Industry %9.3f
format Within_Industry %9.3f
list, separator(2) ab(25)

export excel "$outputdir/Table3.xlsx", replace

cap rm "$outputdir/tab3_p1.dta"
cap rm "$outputdir/tab3_p2.dta"
cap rm "$outputdir/tab3_p3.dta"


