/* ======================================
Project Title: Racial Heterogeneity in the U.S. Structural Transformation and Regional Convergence  
Authors: Minki Kim and Munseob Lee  
Last modified: Aug 4, 2023 

This code replicates Table A1
====================================== */ 

clear all

* Directory
* For replicator: change the directory to your own local ones
local owndir = "C:\replication package"
global datadir_raw = "`owndir'/data/raw" // Raw data stored here
global datadir_proc = "`owndir'/data/proc" // Processed data stored here
global outputdir = "`owndir'/output"
global codedir = "`owndir'/code"

cd "$codedir"

/* -----------------------------------
 Table A1 
 Before running, make sure the years are set to t = 1990 and t_1 = 1940 in Decomposition.do 
----------------------------------- */
foreach race_sample in entire white black {
	cd "$datadir_raw"
	use census1940_2020_raw, clear
	local year_begin 1940
	local year_end 1990
	
	* Identify interstate migrants (not necessarily North-South migrants)
	gen mig_interstate = 0 
	replace mig_interstate = 1 if migrate5 == 3 & year <= 2000 & year != 1950 // migrate5 not available for post 2000 and 1950 
	replace mig_interstate = 1 if migrate1 == 3 & (year > 2000 | year == 1950) // use migrate1 instead

	tab year mig_interstate, nofreq row
	tab year mig_interstate if race == 2, nofreq row

	* Sample without interstate migrants 
	drop if mig_interstate == 1 

	if "`race_sample'" == "entire" {
		tab race
		do "$codedir/DataClearing.do"
		include "$codedir/Decomposition.do"
		tostring dummy, replace
		replace dummy = "Entire Population" if _n == 1
		replace dummy = "Percentage" if _n == 2
		save "$outputdir/tab_a1_p1.dta", replace
	}
	else if "`race_sample'" == "white" {
		keep if race ==1 
		tab race
		do "$codedir/DataClearing.do"
		include "$codedir/Decomposition.do"
		tostring dummy, replace
		replace dummy = "White" if _n == 1
		replace dummy = "Percentage" if _n == 2
		save "$outputdir/tab_a1_p2.dta", replace

	}
	else if "`race_sample'" == "black" {
		keep if race ==2 
		tab race
		do "$codedir/DataClearing.do"
		include "$codedir/Decomposition.do"
		tostring dummy, replace
		replace dummy = "Black" if _n == 1
		replace dummy = "Percentage" if _n == 2
		save "$outputdir/tab_a1_p3.dta", replace

	}
}

/* -----------------------------------
 Generate Table 
----------------------------------- */
cd "$outputdir"

use tab_a1_p1, clear
append using tab_a1_p2
append using tab_a1_p3
save TableA1.dta, replace 

format Total %9.3f
format Labor_Reallocation %9.3f
format Between_Industry %9.3f
format Within_Industry %9.3f
list, separator(2) ab(25)

export excel "$outputdir/TableA1.xlsx", replace

cap rm "$outputdir/tab_a1_p1.dta"
cap rm "$outputdir/tab_a1_p2.dta"
cap rm "$outputdir/tab_a1_p3.dta"


